OC.L10N.register(
    "files",
    {
    "Close" : "बंद करें ",
    "Files" : "फाइलें ",
    "Details" : "विवरण ",
    "New folder" : "नया फ़ोल्डर",
    "Upload" : "अपलोड ",
    "Save" : "सहेजें",
    "Settings" : "सेटिंग्स",
    "Delete" : "हटाना"
},
"nplurals=2; plural=(n != 1);");
